Python: module AIGO.utils.Venn

AIGO.utils.Venn | index /home/dpm/projects/AIGO-0.1.0/AIGO/utils/Venn.py

`PyVenn
Venn Diagrams for python,
both proportional and 'normal'.
Currently draws 2 set diagrams by itself,
passes larger diagrams (normal) on to the R library 'vennerable'
using rpy2 (and numpy).
Should work without rpy2 installed.
Work in progress.
Usage:
vd = VennDiagram ( [ ("One set", [1,2,3]), ("Other Set", [3, 4, 5, 6])])
vd.plot_normal('test_normal.png')
vd.plot_proportional('test_proportional.png')
Requires:
numpy
cairo
Option:
rpy2 ( and the Vennerable R library)
Released under:
The MIT License
Copyright (c) 2010, Florian Finkernagel
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.`

Modules
`` |  |
cairo | math | numpy | unittest

Classes
`` |  | VennDiagram unittest.TestCase(__builtin__.object) TestVennDiagram
class TestVennDiagram(unittest.TestCase)
`` | `These 'unit tests' don't deserve their name - but at least the ascertain that we don't throw an exception.`
| Method resolution order: TestVennDiagram unittest.TestCase __builtin__.object Methods defined here: test_normal(self) test_proportional(self) test_proportional3(self) test_proportional_more_than_3_raises(self) test_proportional_pdf(self) Methods inherited from unittest.TestCase: __call__(self, *args, **kwds) __eq__(self, other) __hash__(self) __init__(self, methodName='runTest') `Create an instance of the class that will use the named test method when executed. Raises a ValueError if the instance does not have a method with the specified name.` __ne__(self, other) __repr__(self) __str__(self) assertAlmostEqual = failUnlessAlmostEqual(self, first, second, places=7, msg=None) `Fail if the two objects are unequal as determined by their difference rounded to the given number of decimal places (default 7) and comparing to zero. Note that decimal places (from zero) are usually not the same as significant digits (measured from the most signficant digit).` assertAlmostEquals = failUnlessAlmostEqual(self, first, second, places=7, msg=None) `Fail if the two objects are unequal as determined by their difference rounded to the given number of decimal places (default 7) and comparing to zero. Note that decimal places (from zero) are usually not the same as significant digits (measured from the most signficant digit).` assertEqual = failUnlessEqual(self, first, second, msg=None) `Fail if the two objects are unequal as determined by the '==' operator.` assertEquals = failUnlessEqual(self, first, second, msg=None) `Fail if the two objects are unequal as determined by the '==' operator.` assertFalse = failIf(self, expr, msg=None) `Fail the test if the expression is true.` assertNotAlmostEqual = failIfAlmostEqual(self, first, second, places=7, msg=None) `Fail if the two objects are equal as determined by their difference rounded to the given number of decimal places (default 7) and comparing to zero. Note that decimal places (from zero) are usually not the same as significant digits (measured from the most signficant digit).` assertNotAlmostEquals = failIfAlmostEqual(self, first, second, places=7, msg=None) `Fail if the two objects are equal as determined by their difference rounded to the given number of decimal places (default 7) and comparing to zero. Note that decimal places (from zero) are usually not the same as significant digits (measured from the most signficant digit).` assertNotEqual = failIfEqual(self, first, second, msg=None) `Fail if the two objects are equal as determined by the '==' operator.` assertNotEquals = failIfEqual(self, first, second, msg=None) `Fail if the two objects are equal as determined by the '==' operator.` assertRaises = failUnlessRaises(self, excClass, callableObj, *args, **kwargs) `Fail unless an exception of class excClass is thrown by callableObj when invoked with arguments args and keyword arguments kwargs. If a different type of exception is thrown, it will not be caught, and the test case will be deemed to have suffered an error, exactly as for an unexpected exception.` assertTrue = failUnless(self, expr, msg=None) `Fail the test unless the expression is true.` assert_ = failUnless(self, expr, msg=None) `Fail the test unless the expression is true.` countTestCases(self) debug(self) `Run the test without collecting errors in a TestResult` defaultTestResult(self) fail(self, msg=None) `Fail immediately, with the given message.` failIf(self, expr, msg=None) `Fail the test if the expression is true.` failIfAlmostEqual(self, first, second, places=7, msg=None) `Fail if the two objects are equal as determined by their difference rounded to the given number of decimal places (default 7) and comparing to zero. Note that decimal places (from zero) are usually not the same as significant digits (measured from the most signficant digit).` failIfEqual(self, first, second, msg=None) `Fail if the two objects are equal as determined by the '==' operator.` failUnless(self, expr, msg=None) `Fail the test unless the expression is true.` failUnlessAlmostEqual(self, first, second, places=7, msg=None) `Fail if the two objects are unequal as determined by their difference rounded to the given number of decimal places (default 7) and comparing to zero. Note that decimal places (from zero) are usually not the same as significant digits (measured from the most signficant digit).` failUnlessEqual(self, first, second, msg=None) `Fail if the two objects are unequal as determined by the '==' operator.` failUnlessRaises(self, excClass, callableObj, *args, **kwargs) `Fail unless an exception of class excClass is thrown by callableObj when invoked with arguments args and keyword arguments kwargs. If a different type of exception is thrown, it will not be caught, and the test case will be deemed to have suffered an error, exactly as for an unexpected exception.` id(self) run(self, result=None) setUp(self) `Hook method for setting up the test fixture before exercising it.` shortDescription(self) `Returns a one-line description of the test, or None if no description has been provided. The default implementation of this method returns the first line of the specified test method's docstring.` tearDown(self) `Hook method for deconstructing the test fixture after testing it.` Data descriptors inherited from unittest.TestCase: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` Data and other attributes inherited from unittest.TestCase: failureException = <type 'exceptions.AssertionError'> `Assertion failed.`
class VennDiagram
`` |  | Methods defined here: __init__(self, name_set_tuples_or_dict) plot_normal(self, output_filename, width=8, colors=None) plot_proportional(self, output_filename, width=8, colors=None) Data and other attributes defined here: default_colors = [(0.89411764705882357, 0.10196078431372549, 0.10980392156862745), (0.21568627450980393, 0.49411764705882355, 0.72156862745098038), (0.30196078431372547, 0.68627450980392157, 0.29019607843137257)]

Functions
`` |  | load_r()

Data
`` |  | robjects = None